@@ -219,7 +219,7 @@ fn run_app(opt: Opt) -> Result<()> {
             } else {
                 crate::conf::get_config_file()?
             };
-            conf::FileSettings::validate(config_path)?;
+            conf::FileSettings::validate(config_path, true)?; // TODO: test for tty/interaction
             return Ok(());
         }
         Some(SubCommand::CreateConfig { path }) => {
